@@ -1,4 +1,5 @@
 from __future__ import annotations
+from typing import List
 import logging
 
 from dynamicprompts import constants
@@ -12,7 +13,7 @@ class BatchedCombinatorialPromptGenerator(PromptGenerator):
         self._generator = generator
         self._batches = batches
 
-    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> list[str]:
+    def generate(self, template, max_prompts=constants.MAX_IMAGES) -> List[str]:
         images = []
 
         for _ in range(self._batches):
