@@ -5,5 +5,5 @@ from .promptgenerator import PromptGenerator
 
 
 class DummyGenerator(PromptGenerator):
-    def generate(self, template, num_images) -> List[str]:
+    def generate(self, template, num_images=1) -> List[str]:
         return num_images * [template]
