@@ -1,4 +1,5 @@
 from __future__ import annotations
+
 from typing import List
 
 import logging
@@ -7,12 +8,21 @@ import random
 import requests
 
 from dynamicprompts.generators.promptgenerator import PromptGenerator, GeneratorException
+from dynamicprompts.generators import DummyGenerator
 
 
 logger = logging.getLogger(__name__)
 
 class FeelingLuckyGenerator(PromptGenerator):
+    def __init__(self, generator: PromptGenerator|None=None):
+        if generator is None:
+            self._generator = DummyGenerator()
+        else:
+            self._generator = generator
+
     def generate(self, search_query, num_prompts: int) -> List[str]:
+        search_query = self._generator.generate(search_query, 1)[0]
+
         if search_query.strip() == "":
             query = random.randint(0, 10000000)
         else:
