@@ -1,9 +1,11 @@
 from __future__ import annotations
+from typing import List
+
 from abc import ABC, abstractmethod
 
 class PromptGenerator(ABC):
     @abstractmethod
-    def generate(self, *args, **kwargs) -> list[str]:
+    def generate(self, *args, **kwargs) -> List[str]:
         pass
 
 
