@@ -19,6 +19,7 @@ class RandomPromptGenerator(PromptGenerator):
         wildcard_manager: WildcardManager,
         seed: int | None = None,
         unlink_seed_from_prompt: bool = constants.UNLINK_SEED_FROM_PROMPT,
+        ignore_whitespace=False
     ):
         self._wildcard_manager = wildcard_manager
         self._unlink_seed_from_prompt = unlink_seed_from_prompt
@@ -30,7 +31,7 @@ class RandomPromptGenerator(PromptGenerator):
             if seed is not None:
                 self._random.seed(seed)
 
-        self._generator = RandomGenerator(wildcard_manager)
+        self._generator = RandomGenerator(wildcard_manager, ignore_whitespace=ignore_whitespace)
 
     def generate(self, template, num_images=1) -> List[str]:
         if template is None or len(template) == 0:
