@@ -15,7 +15,7 @@ logger = logging.getLogger(__name__)
 
 
 class RandomSequenceCommand(SequenceCommand):
-    def __init__(self, tokens: List[Command] | None = None, separator=" "):
+    def __init__(self, tokens: List[Command] | None = None, separator=""):
         self._sep = separator
         super().__init__(tokens)
 
@@ -28,13 +28,14 @@ class RandomSequenceCommand(SequenceCommand):
 
 
 class RandomWildcardCommand(Command):
-    def __init__(self, wildcard_manager, token: str):
+    def __init__(self, wildcard_manager, builder: ActionBuilder, token: str):
         super().__init__(token)
         self._wildcard_manager = wildcard_manager
         self._wildcard = token[0]
+        self._builder = builder
 
     def prompts(self) -> Iterable[str]:
-        generator = RandomGenerator(self._wildcard_manager)
+        generator = self._builder.create_generator()
         values = self._wildcard_manager.get_all_values(self._wildcard)
         if len(values) == 0:
             logger.warning(f"No values found for wildcard {self._wildcard}")
@@ -86,26 +87,34 @@ class RandomVariantCommand(Command):
 
 
 class RandomActionBuilder(ActionBuilder):
+    def __init__(self, wildcard_manager: WildcardManager, seq_sep="", ignore_whitespace=False):
+        super().__init__(wildcard_manager, ignore_whitespace=ignore_whitespace)
+        self._seq_sep = seq_sep
+
     def create_variant_command(self, variants, min_bound=1, max_bound=1, sep=","):
         return RandomVariantCommand(variants, min_bound, max_bound, sep)
 
     def create_wildcard_command(self, token: str):
-        return RandomWildcardCommand(self._wildcard_manager, token)
+        return RandomWildcardCommand(self._wildcard_manager, self, token)
 
     def create_sequence_command(self, token_list: List[Command]):
-        return RandomSequenceCommand(token_list)
+        return RandomSequenceCommand(token_list, separator=self._seq_sep)
+
+    def create_generator(self):
+        return RandomGenerator(self._wildcard_manager, ignore_whitespace=self._ignore_whitespace)
 
 
 class RandomGenerator:
-    def __init__(self, wildcard_manager: WildcardManager, rand=None):
+    def __init__(self, wildcard_manager: WildcardManager, rand=None, ignore_whitespace=False):
         if rand is None:
             self._random = random
         else:
             self._random = rand
         self._wildcard_manager = wildcard_manager
+        self._ignore_whitespace = ignore_whitespace
 
     def get_action_builder(self) -> ActionBuilder:
-        return RandomActionBuilder(self._wildcard_manager)
+        return RandomActionBuilder(self._wildcard_manager, seq_sep="", ignore_whitespace=self._ignore_whitespace)
 
     def configure_parser(self):
         builder = self.get_action_builder()
@@ -113,7 +122,7 @@ class RandomGenerator:
 
         return parser.prompt
 
-    def generate_prompts(self, prompt: str, num_prompts: int) -> List[str]:
+    def generate_prompts(self, prompt: str, num_prompts: int = 0) -> List[str]:
         if len(prompt) == 0:
             return []
 
@@ -124,8 +133,21 @@ class RandomGenerator:
         squash_whitespace = lambda s: " ".join(s.split())
 
         generated_prompts = []
+        if len(tokens) == 0:
+            return []
+
         for i in range(num_prompts):
+            
+
             prompts = list(tokens[0].prompts())
-            generated_prompts.append(squash_whitespace(prompts[0]))
+            if len(prompts) == 0:
+                
+                continue
+            if self._ignore_whitespace:
+                prompt = squash_whitespace(prompts[0])
+            else:
+                prompt = prompts[0]
+
+            generated_prompts.append(prompt)
 
         return generated_prompts
